local MarketAddition= ...

MarketAdditionPrefix = "MARKET_ADDITION_V2"

if (foundation.getGameVersion == nil or version.cmp(foundation.getGameVersion(), "1.6") < 0) then
    MarketAddition:log("Hello World: version 1.5")
    MarketAdditionTagBehaviorWork = "WORK_BEHAVIOR"
    _StallBuildingZone = { Polygon = polygon.createRectangle( {4, 4} ) } 
else
    MarketAddition:log("Hello World: version " .. foundation.getGameVersion())
    MarketAdditionTagBehaviorWork = "BEHAVIOR_WORK"
    if version.cmp(foundation.getGameVersion(), "1.6.6") < 0 then
        MarketAddition:log("Hello World: version 1.6.5")
        _StallBuildingZone = { Polygon = polygon.createRectangle( {4, 4} ) } 
    else
        MarketAddition:log("Hello World: version 1.6.6")
        _StallBuildingZone = { ZoneEntryList = {
            { Polygon = polygon.createRectangle( {4, 4} ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true } }
        }}
        MarketAddition:registerEnumValue ("BUILDING_PART_TYPE", "EXTENSION")
   end
end

-- Register model for stocking asset
MarketAddition:registerAssetId("models/crate.fbx/Prefab/crate", MarketAdditionPrefix .. "_CRATE")
MarketAddition:dofile("scripts/hatmaker.lua")
MarketAddition:dofile("scripts/knifegrinder.lua")

MarketAddition:override({
    Id = "MONUMENT_MARKET",
    BuildingPartSetList = {
                Action = "APPEND",
		{
			Name = MarketAdditionPrefix .. "_PARTSETLIST_NAME",
                	BuildingPartList = {
                            MarketAdditionPrefix .. "_HAT_STALL_PART",
                            MarketAdditionPrefix .. "_HAT_WORKSHOP_PART",
                            MarketAdditionPrefix .. "_KNIFE_GRINDER_PART",
                            MarketAdditionPrefix .. "_ROOF_CENTER_PART",
                            MarketAdditionPrefix .. "_ROOF_CORNER_PART",
                            MarketAdditionPrefix .. "_ROOF_ENTRANCE_PART",
                            MarketAdditionPrefix .. "_HAT_SIGN_PART",
                            MarketAdditionPrefix .. "_KNIFE_GRINDER_SIGN_PART"
                        }
                }
    }
})

MarketAddition:register({
		DataType = "BUILDING_FUNCTION_MARKET",
                Id = MarketAdditionPrefix .. "_HATMAKER_FUNCTION",
                TypeList = { "GOODS" },
                IsOverrideCapacity = true,
                CapacityPerSlot = 50,
		WorkerCapacity = 1,                
                RelatedJob = { Job = MarketAdditionPrefix .. "_HATMAKER", Behavior = MarketAdditionTagBehaviorWork },
                InputInventoryCapacity = {
			{ Resource = "WOOLEN_CLOTH", Quantity = 50 }
                },
                ResourceListNeeded = {
                	{ Resource = "WOOLEN_CLOTH", Quantity = 1 }
                },
                ResourceProduced = {
			{ Resource = MarketAdditionPrefix .. "_HAT", Quantity = 1 }
                }
})

MarketAddition:register({
		DataType = "BUILDING_FUNCTION_MARKET",
                Id = MarketAdditionPrefix .. "_KNIFEGRINDER_FUNCTION",
                TypeList = { "GOODS" },
                IsOverrideCapacity = true,
                CapacityPerSlot = 50,
		WorkerCapacity = 1,
                RelatedJob = { Job = MarketAdditionPrefix .. "_KNIFEGRINDER", Behavior = MarketAdditionTagBehaviorWork },
                InputInventoryCapacity = {
			{ Resource = "TOOL", Quantity = 50 }
                },
                ResourceListNeeded = {
                	{ Resource = "TOOL", Quantity = 1 }
                },
                ResourceProduced = {
			{ Resource = MarketAdditionPrefix .. "_KNIFE", Quantity = 1 }
                }
})

function registerMarketPart( _namePrefab, _nameAsset, _nameFunction)
    -- Register prefab nodes (currently only one core model)
    MarketAddition:registerAssetId("models/" .. _namePrefab .. "Part", MarketAdditionPrefix .. "_" .. _nameAsset .. "_PREFAB")

    -- Register the building part
    MarketAddition:register({
	DataType = "BUILDING_PART",
	Id = MarketAdditionPrefix .. "_" .. _nameAsset .. "_PART",
	Name = MarketAdditionPrefix .. "_" .. _nameAsset .. "_NAME",
	Description = MarketAdditionPrefix .. "_" .. _nameAsset .. "_DESC",
	Category = "CORE",
        BuildingZone = _StallBuildingZone,
	Mover = { DataType = "BUILDING_PART_MOVER_INSTANCE" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = MarketAdditionPrefix .. "_" .. _nameAsset .. "_PREFAB"
	},
	Cost = {
		UpkeepCost = {
			{ Resource = "GOLD", Quantity = 1 }
		},
		RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "WOOD", Quantity = 5 }
		}
	},
	AssetBuildingFunction = _nameFunction
    })

    -- Register grounding components
    MarketAddition:registerPrefabComponent("models/" .. _namePrefab .. "Part", {
	DataType = "COMP_GROUNDED"
    })

    -- Override building part components properties (generated by the building asset processor) to add building zones
    MarketAddition:registerPrefabComponent("models/" .. _namePrefab .. "Part", {
	DataType = "COMP_BUILDING_PART",
	HasBuildingZone = true,
	BuildingZone = { 4, 4 }
    })
end

registerMarketPart( "hatmaker.fbx/Prefab/marketAddition/hatStall", "HAT_STALL", "BUILDING_FUNCTION_GOODS_MARKET")
registerMarketPart( "hatmaker.fbx/Prefab/marketAddition/hatWorkshop", "HAT_WORKSHOP", MarketAdditionPrefix .. "_HATMAKER_FUNCTION")
registerMarketPart( "knifegrinder.fbx/Prefab/marketAddition/knifeGrinder", "KNIFE_GRINDER", MarketAdditionPrefix .. "_KNIFEGRINDER_FUNCTION")

MarketAddition:registerAssetId("models/knifegrinder.fbx/Prefab/marketAddition/knifeGrinderPart/step_2_B_makg/meule_makg/SmokeEmitter_makg", MarketAdditionPrefix .. "_KNIFEGRINDER_SMOKE_EMITTER_PREFAB")

MarketAddition:registerPrefabComponent("models/knifegrinder.fbx/Prefab/marketAddition/knifeGrinderPart", {
	DataType = "COMP_BUILDING_PART",
	FeedbackComponentListToActivate = {
		{ MarketAdditionPrefix .. "_KNIFEGRINDER_SMOKE_EMITTER_PREFAB", "COMP_PARTICLE_EMITTER_TOGGLE" }
	}
})

-- Register particle system

MarketAddition:registerPrefabComponent("models/knifegrinder.fbx/Prefab/marketAddition/knifeGrinderPart/step_2_B_makg/meule_makg/SmokeEmitter_makg", {
	DataType = "COMP_PARTICLE_EMITTER",
	ParticleSystem = "PARTICLE_SYSTEM_BLACKSMITH_GRIND",
	IsPlaying = true,
	IsEmitting = false
})

MarketAddition:registerPrefabComponent("models/knifegrinder.fbx/Prefab/marketAddition/knifeGrinderPart/step_2_B_makg/meule_makg/SmokeEmitter_makg", {
	DataType = "COMP_PARTICLE_EMITTER_TOGGLE",
	Enabled = false
})


function registerRoofPart( _namePrefab, _nameAsset)
    -- Register prefab nodes (currently only one core model)
    MarketAddition:registerAssetId("models/" .. _namePrefab .. "Part", MarketAdditionPrefix .. "_" .. _nameAsset .. "_PREFAB")

    -- Register the hatmaker workplace part
    MarketAddition:register({
	DataType = "BUILDING_PART",
	Id = MarketAdditionPrefix .. "_" .. _nameAsset .. "_PART",
	Name = MarketAdditionPrefix .. "_" .. _nameAsset .. "_NAME",
	Description = MarketAdditionPrefix .. "_" .. _nameAsset .. "_DESC",
	Category = "CORE",
        BuildingZone = _StallBuildingZone,
	Mover = { DataType = "BUILDING_PART_MOVER_INSTANCE" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = MarketAdditionPrefix .. "_" .. _nameAsset .. "_PREFAB"
	},
	Cost = {
		UpkeepCost = {
			{ Resource = "GOLD", Quantity = 0 }
		},
		RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "WOOD", Quantity = 5 }
		}
	}
    })

    -- Override building part components properties (generated by the building asset processor) to add building zones
    MarketAddition:registerPrefabComponent("models/" .. _namePrefab .. "Part", {
	DataType = "COMP_BUILDING_PART",
	HasBuildingZone = true,
	BuildingZone = { 4, 4 }
    })
end

registerRoofPart( "hatmaker.fbx/Prefab/marketAddition/roofCenter", "ROOF_CENTER")
registerRoofPart( "hatmaker.fbx/Prefab/marketAddition/roofCorner", "ROOF_CORNER")

function registerEntrancePart( _namePrefab, _nameAsset)
    -- Register prefab nodes (currently only one core model)
    MarketAddition:registerAssetId("models/" .. _namePrefab .. "Part", MarketAdditionPrefix .. "_" .. _nameAsset .. "_PREFAB")

    -- Register the hatmaker workplace part
    MarketAddition:register({
	DataType = "BUILDING_PART",
	Id = MarketAdditionPrefix .. "_" .. _nameAsset .. "_PART",
	Name = MarketAdditionPrefix .. "_" .. _nameAsset .. "_NAME",
	Description = MarketAdditionPrefix .. "_" .. _nameAsset .. "_DESC",
	Category = "EXTENSION",
	Mover = { DataType = "BUILDING_PART_MOVER_INSTANCE" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = MarketAdditionPrefix .. "_" .. _nameAsset .. "_PREFAB"
	},
	Cost = {
		UpkeepCost = {
			{ Resource = "GOLD", Quantity = 0 }
		},
		RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "WOOD", Quantity = 0 }
		}
	}
    })

    -- Override building part components properties (generated by the building asset processor) to add building zones
    MarketAddition:registerPrefabComponent("models/" .. _namePrefab .. "Part", {
	DataType = "COMP_BUILDING_PART",
	HasBuildingZone = false,
	BuildingZone = { 0, 0 }
    })
end

registerEntrancePart( "hatmaker.fbx/Prefab/marketAddition/roofEntrance", "ROOF_ENTRANCE")
registerEntrancePart( "hatmaker.fbx/Prefab/marketAddition/hatSign", "HAT_SIGN", NIL)
registerEntrancePart( "knifegrinder.fbx/Prefab/marketAddition/knifeGrinderSign", "KNIFE_GRINDER_SIGN", NIL)


